==> haskell-wai-websockets-3.0.1.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-3eVIHcerztl4XjYY9UVPnN
key: wai-websockets-3.0.1.1-3eVIHcerztl4XjYY9UVPnN
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: c6a5fc6c82afa0828571df229394b98f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-3eVIHcerztl4XjYY9UVPnN
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 case-insensitive-1.2.0.7-43Vuzc2uQwC59iyLU6pVOg
    http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG transformers-0.5.2.0
    wai-3.2.1.1-9mMHgVB1wYz4uCkr33AuWK
    websockets-0.10.0.0-AWDg5JavrNQDcraaSZ5ezB
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-websockets
version: 3.0.1.1
id: wai-websockets-3.0.1.1-1Ejfv1kpmkU79zeDjyfg0n
key: wai-websockets-3.0.1.1-1Ejfv1kpmkU79zeDjyfg0n
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.
category: Web, Yesod
author: Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
exposed: True
exposed-modules:
    Network.Wai.Handler.WebSockets
abi: 92bca2ed8995cbad0c55b8e185d17eec
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-websockets-3.0.1.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/wai-websockets-3.0.1.1
hs-libraries: HSwai-websockets-3.0.1.1-1Ejfv1kpmkU79zeDjyfg0n
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 case-insensitive-1.2.0.8-6RHKQz6dPK3ENaPtabAPQ
    http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG transformers-0.5.2.0
    wai-3.2.1.1-G3x7tNXaUUGBY6K4SzJOAN
    websockets-0.10.0.0-1VXJGnIGmRdJlqMpc1L90W
haddock-interfaces: /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock
haddock-html: /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
